@@ -69,6 +69,7 @@ class TelegramBot:
         self._timeout_msg = "timed out. took too long to respond"
         self._process_running_msg = "failed: you already have an active process"
         self._standart_timeout = 30
+        self._standard_parse_mode = ""
         self.commands = {
             self._cancel_command: self._cancel_func
         }
@@ -85,6 +86,10 @@ class TelegramBot:
         
         self._logging = True
 
+    def set_standard_parse_mode(self, parse_mode):
+        parse_mode = parse_mode.lower()
+        self._standard_parse_mode = parse_mode
+
     def enable_console_logging(self, state=True):
         self.console_logging = state
 
@@ -181,6 +186,10 @@ class TelegramBot:
     def set_command(self, command, function):
         if command.startswith("/") and len(command) > 1:
             command = command[1:]
+        if " " in command or "\n" in command or "\t" in command:
+            raise Exception("Command-String must not include whitespace")
+        if not command:
+            raise Exception("no command provided")
         self.commands[command] = function
         self.log(f'Set Command Handler for "/{command}"', CONFIG)
 
@@ -190,13 +199,15 @@ class TelegramBot:
 
     def _run_command(self, command_text, message):
         for command, user_func in self.commands.items():
-            if command == command_text:
+            if command == command_text.split()[0]:
                 info_object = self._make_info_object(message)
                 self._run_user_func(user_func, info_object)
                 return True
         return False
 
-    def send_message(self, chat_id: str, msg: str, parse_mode="") -> bool:
+    def send_message(self, chat_id: str, msg: str, parse_mode=None) -> bool:
+        if parse_mode == None:
+            parse_mode = self._standard_parse_mode
         result = self._send_request("sendMessage", {
             "chat_id": str(chat_id),
             "text": str(msg),
@@ -310,7 +321,7 @@ class TelegramBot:
         ui.input_from = self._wait_input
         ui.bot = self
 
-        if ui.text.startswith("/") and len(ui.text) > 0:
+        if ui.text.startswith("/") and len(ui.text) > 1:
             ui.arguments = self._get_args(ui.text)
         else:
             ui.arguments = list()
